drop table if exists Maladies ;
drop table if exists Animaux ;
drop table if exists Gardiens ;
drop table if exists Cages ;
drop table if exists Responsables ;
drop table if exists Employes ;


create table Employes (
   nomE varchar(20),
   adresse varchar(20) not null,
   constraint Employes_C1 primary key (nomE)
);

create table Responsables (
   noAllee int,
   nomE varchar(20) not null,
   constraint Responsables_C1 primary key (noAllee),
   constraint Responsables_C2
       foreign key (nomE) references Employes (nomE)
       on delete cascade,
   constraint Responsables_C3 check (noAllee between 1 and 999)
);

create table Cages (
   noCage int,
   fonction varchar(20) not null,
   noAllee int not null,
   constraint Cages_C1 primary key (noCage),
   constraint Cages_C2 check (noCage between 1 and 999),
   constraint Cages_C3 foreign key (noAllee) references Responsables (noAllee) on delete cascade
);

create table Gardiens (
   noCage int,
   nomE varchar(20),
   constraint Gardiens_C1 primary key (noCage, nomE),
   constraint Gardiens_C2
       foreign key (nomE) references Employes (nomE) on delete cascade,
   constraint Gardiens_C3
       foreign key (noCage) references Cages (noCage)
       on delete cascade);

create table Animaux (
   nomA varchar(20),
   sexe enum('male','femelle','hermaphrodite') NOT NULL DEFAULT 'male',
   type varchar(15) not null,
   pays varchar(20) DEFAULT 'France',
   anNais int,
   noCage int not null,
   primary key (nomA),
   constraint Animaux_C3 check (anNais >= 1900),
   constraint Animaux_C4 foreign key(noCage) references Cages (noCage)
       on delete cascade
);

create table Maladies (
   nomA varchar(20),
   nomM varchar(20),
   constraint Maladies_C1 primary key (nomA,nomM),
   constraint Maladies_C2 
       foreign key (nomA) references Animaux (nomA)
       on delete cascade
);

insert into Employes values ("Peyrin","Noumea");
insert into Employes values ("Berrut","Sarteme");
insert into Employes values ("Sicard","Calvi");
insert into Employes values ("Voiron","Pointe a Pitre");
insert into Employes values ("Scholl","Ushuaia");
insert into Employes values ("Adiba","Papeete");

insert into Responsables values (10, "Peyrin");
insert into Responsables values (1, "Adiba");
insert into Responsables values (2, "Voiron");

insert into Cages values (11, "enclos", 10);
insert into Cages values (1, "fosse", 1);
insert into Cages values (2, "aquarium", 1);
insert into Cages values (3, "voliere", 2);
insert into Cages values (4, "grand aquarium", 1);
insert into Cages values (12, "enclos", 10);

insert into Animaux values ("Charly","male","lion","Kenya",1990,12);
insert into Animaux values ("Arthur", "male", "ours", "France",1980,1);
insert into Animaux values ("Chloe", "femelle", "pie","France",1991,3);
insert into Animaux values ("Milou", "male", "leopard","France",1993,11);
insert into Animaux values ("Tintin", "male", "leopard","France",1993,11);
insert into Animaux values ("Charlotte", "femelle", "lion","Kenya",1992,12);

insert into Maladies values ("Charly", "Rage de dents");
insert into Maladies values ("Charly", "Grippe");
insert into Maladies values ("Milou", "Angine");
insert into Maladies values ("Chloe", "Grippe");

insert into Gardiens values (11, "Scholl");
insert into Gardiens values (12, "Berrut");
insert into Gardiens values (11, "Sicard");
insert into Gardiens values (11, "Berrut");
insert into Gardiens values (1, "Scholl");
insert into Gardiens values (3, "Scholl");
insert into Gardiens values (12, "Scholl");