--
-- Base de données: `zoo`
--

CREATE DATABASE IF NOT EXISTS zoo;

-- --------------------------------------------------------

--
-- Structure de la table `Animaux`
--

CREATE TABLE IF NOT EXISTS `Animaux` (
	`nomA` varchar(20) NOT NULL DEFAULT '',
	`sexe` enum('male','femelle','hermaphrodite') NOT NULL DEFAULT 'male',
	`type` varchar(15) NOT NULL,
	`pays` varchar(20) DEFAULT 'France',
	`anNais` int(11) DEFAULT NULL,
	`noCage` int(11) NOT NULL,
	PRIMARY KEY (`nomA`),
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Contenu de la table `Animaux`
--

INSERT INTO `Animaux` (`nomA`, `sexe`, `type`, `pays`, `anNais`, `noCage`) VALUES
('Arthur', 'male', 'ours', 'France', 1980, 1),
('Charlotte', 'femelle', 'lion', 'Kenya', 1992, 12),
('Charly', 'male', 'lion', 'Kenya', 1990, 12),
('Chloe', 'femelle', 'pie', 'France', 1991, 3),
('Milou', 'male', 'leopard', 'France', 1993, 11),
('Tintin', 'male', 'leopard', 'France', 1993, 11);

-- --------------------------------------------------------

--
-- Structure de la table `Cages`
--

CREATE TABLE IF NOT EXISTS `Cages` (
  `noCage` int(11) NOT NULL DEFAULT '0',
  `fonction` varchar(20) NOT NULL,
  `noAllee` int(11) NOT NULL,
  PRIMARY KEY (`noCage`),
  KEY `Cages_C3` (`noAllee`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Contenu de la table `Cages`
--

INSERT INTO `Cages` (`noCage`, `fonction`, `noAllee`) VALUES
(1, 'fosse', 1),
(2, 'aquarium', 1),
(3, 'voliere', 2),
(4, 'grand aquarium', 1),
(11, 'enclos', 10),
(12, 'enclos', 10);

-- --------------------------------------------------------

--
-- Structure de la table `Employes`
--

CREATE TABLE IF NOT EXISTS `Employes` (
  `nomE` varchar(20) NOT NULL DEFAULT '',
  `adresse` varchar(20) NOT NULL,
  PRIMARY KEY (`nomE`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Contenu de la table `Employes`
--

INSERT INTO `Employes` (`nomE`, `adresse`) VALUES
('Adiba', 'Papeete'),
('Berrut', 'Sarteme'),
('Peyrin', 'Noumea'),
('Scholl', 'Ushuaia'),
('Sicard', 'Calvi'),
('Voiron', 'Pointe a Pitre');

-- --------------------------------------------------------

--
-- Structure de la table `Gardiens`
--

CREATE TABLE IF NOT EXISTS `Gardiens` (
  `noCage` int(11) NOT NULL DEFAULT '0',
  `nomE` varchar(20) NOT NULL DEFAULT '',
  PRIMARY KEY (`noCage`,`nomE`),
  KEY `Gardiens_C2` (`nomE`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Contenu de la table `Gardiens`
--

INSERT INTO `Gardiens` (`noCage`, `nomE`) VALUES
(11, 'Berrut'),
(12, 'Berrut'),
(1, 'Scholl'),
(3, 'Scholl'),
(11, 'Scholl'),
(12, 'Scholl'),
(11, 'Sicard');

-- --------------------------------------------------------

--
-- Structure de la table `Maladies`
--

CREATE TABLE IF NOT EXISTS `Maladies` (
  `nomA` varchar(20) NOT NULL DEFAULT '',
  `nomM` varchar(20) NOT NULL DEFAULT '',
  PRIMARY KEY (`nomA`,`nomM`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Contenu de la table `Maladies`
--

INSERT INTO `Maladies` (`nomA`, `nomM`) VALUES
('Charly', 'Grippe'),
('Charly', 'Rage de dents'),
('Chloe', 'Grippe'),
('Milou', 'Angine');

-- --------------------------------------------------------

--
-- Structure de la table `Responsables`
--

CREATE TABLE IF NOT EXISTS `Responsables` (
  `noAllee` int(11) NOT NULL DEFAULT '0',
  `nomE` varchar(20) NOT NULL,
  PRIMARY KEY (`noAllee`),
  KEY `Responsables_C2` (`nomE`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Contenu de la table `Responsables`
--

INSERT INTO `Responsables` (`noAllee`, `nomE`) VALUES
(1, 'Adiba'),
(10, 'Peyrin'),
(2, 'Voiron');

--
-- Contraintes pour les tables exportées
--

--
-- Contraintes pour la table `Animaux`
--
ALTER TABLE `Animaux`
  ADD CONSTRAINT `Animaux_C4` FOREIGN KEY (`noCage`) REFERENCES `Cages` (`noCage`) ON DELETE CASCADE;

--
-- Contraintes pour la table `Cages`
--
ALTER TABLE `Cages`
  ADD CONSTRAINT `Cages_C3` FOREIGN KEY (`noAllee`) REFERENCES `Responsables` (`noAllee`) ON DELETE CASCADE;

--
-- Contraintes pour la table `Gardiens`
--
ALTER TABLE `Gardiens`
  ADD CONSTRAINT `Gardiens_C2` FOREIGN KEY (`nomE`) REFERENCES `Employes` (`nomE`) ON DELETE CASCADE,
  ADD CONSTRAINT `Gardiens_C3` FOREIGN KEY (`noCage`) REFERENCES `Cages` (`noCage`) ON DELETE CASCADE;

--
-- Contraintes pour la table `Maladies`
--
ALTER TABLE `Maladies`
  ADD CONSTRAINT `Maladies_C2` FOREIGN KEY (`nomA`) REFERENCES `Animaux` (`nomA`) ON DELETE CASCADE;

--
-- Contraintes pour la table `Responsables`
--
ALTER TABLE `Responsables`
  ADD CONSTRAINT `Responsables_C2` FOREIGN KEY (`nomE`) REFERENCES `Employes` (`nomE`) ON DELETE CASCADE;

/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
